==> lxqt-runner-0.9.0.tar.xz: lxqt-runner-0.9.0/translations/lxqt-runner_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Настройки ускорителя запуска</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Позиция:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Показывать на:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="56"/>
        <source>Shortcut:</source>
        <translation>Сочетание клавиш:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="60"/>
        <source>Top edge of the screen</source>
        <translation>Верхней границе экрана</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Center of the screen</source>
        <translation>В центре экрана</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>Активном экране</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Всегда на %1 экране</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Сброс</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Ускоритель запуска программ </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="92"/>
        <source>Configure</source>
        <translation>Настроить</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="96"/>
        <source>Clear History</source>
        <translation>Очистить историю</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="337"/>
        <source>Show/hide runner dialog</source>
        <translation>Показать/скрыть окно ускорителя</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="388"/>
        <source>History</source>
        <translation>Из истории</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="779"/>
        <source>Mathematics</source>
        <translation>Математика</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="840"/>
        <source>Power Management</source>
        <translation>Управление энергопотреблением</translation>
    </message>
</context>
</TS>

==> lxqt-runner_0.14.0.orig.tar.xz: lxqt-runner-0.14.0/translations/lxqt-runner_ru_RU.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Настройки ускорителя запуска</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Позиция:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Показывать на:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="46"/>
        <source>Show history first</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="53"/>
        <source>Store/show history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="60"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="63"/>
        <source>Show list with:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="70"/>
        <source> item(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="90"/>
        <source>Shortcut:</source>
        <translation>Сочетание клавиш:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Верхней границе экрана</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>В центре экрана</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="68"/>
        <source>Focused screen</source>
        <translation>Активном экране</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="72"/>
        <source>Always on screen %1</source>
        <translation>Всегда на %1 экране</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="81"/>
        <source>Reset</source>
        <translation>Сброс</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Ускоритель запуска программ </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="94"/>
        <source>Configure</source>
        <translation>Настроить</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="98"/>
        <source>Clear History</source>
        <translation>Очистить историю</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="351"/>
        <source>Show/hide runner dialog</source>
        <translation>Показать/скрыть окно ускорителя</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Из истории</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="824"/>
        <source>Mathematics</source>
        <translation>Математика</translation>
    </message>
</context>
</TS>
